@@ -918,7 +918,6 @@ prefs_cb (BonoboUIComponent *ui_container,
 {
   FusaAppletData *adata;
   GladeXML *xml;
-  GConfClient *client;
   GtkWidget *warning_box, *label, *username_radio, *text_radio, *icon_radio,
     *check;
   gchar *key, *value;
@@ -939,8 +938,6 @@ prefs_cb (BonoboUIComponent *ui_container,
   if (!xml)
     return;
 
-  client = gconf_client_get_default ();
-
   adata->prefs = glade_xml_get_widget (xml, "prefs_dialog");
   gtk_dialog_set_default_response (GTK_DIALOG (adata->prefs),
 				   GTK_RESPONSE_CLOSE);
@@ -998,7 +995,7 @@ prefs_cb (BonoboUIComponent *ui_container,
 
   label_setup_done = FALSE;
   key = panel_applet_gconf_get_full_key (adata->applet, DISPLAY_KEY);
-  if (has_lockdown || !gconf_client_key_is_writable (client, key, NULL))
+  if (has_lockdown || !gconf_client_key_is_writable (adata->client, key, NULL))
     {
       GtkWidget *label;
 
@@ -1023,7 +1020,7 @@ prefs_cb (BonoboUIComponent *ui_container,
   g_signal_connect (check, "toggled",
 		    G_CALLBACK (prefs_lock_check_toggled_cb), adata);
   key = panel_applet_gconf_get_full_key (adata->applet, LOCK_KEY);
-  if (has_lockdown || !gconf_client_key_is_writable (client, key, NULL))
+  if (has_lockdown || !gconf_client_key_is_writable (adata->client, key, NULL))
     {
       gtk_widget_set_sensitive (check, FALSE);
 
@@ -1051,7 +1048,7 @@ prefs_cb (BonoboUIComponent *ui_container,
   g_signal_connect (check, "toggled",
 		    G_CALLBACK (prefs_xnest_check_toggled_cb), adata);
   key = panel_applet_gconf_get_full_key (adata->applet, USE_XNEST_KEY);
-  if (has_lockdown || !gconf_client_key_is_writable (client, key, NULL))
+  if (has_lockdown || !gconf_client_key_is_writable (adata->client, key, NULL))
     {
       gtk_widget_set_sensitive (check, FALSE);
 
@@ -1071,8 +1068,6 @@ prefs_cb (BonoboUIComponent *ui_container,
   g_free (key);
   
   gtk_window_present (GTK_WINDOW (adata->prefs));
-
-  g_object_unref (client);
 }
 
 static void
@@ -2407,7 +2402,7 @@ fusa_applet_data_free (FusaAppletData *adata)
     gtk_widget_destroy (adata->prefs);
 
   gconf_client_notify_remove (adata->client, adata->client_notify_applet_id);
-  gconf_client_notify_remove (adata->client, adata->client_notify_applet_id);
+  gconf_client_notify_remove (adata->client, adata->client_notify_global_id);
   gconf_client_remove_dir (adata->client, GLOBAL_DIR, NULL);
   g_object_unref (adata->client);
   g_object_unref (adata->manager);
