@@ -1065,6 +1065,9 @@ process_display_updates (FusaManager *manager,
 static void
 display_closure_free (DisplayClosure *closure)
 {
+  if (!closure)
+    return;
+
   if (closure->data && closure->notify)
     (*closure->notify) (closure->data);
 
@@ -1547,6 +1550,9 @@ dm_op_threadfunc (gpointer data)
 
       if (op->manager)
 	g_object_unref (op->manager);
+
+      if (op->closure)
+        display_closure_free (op->closure);
       GDK_THREADS_LEAVE ();
 
       g_free (op);
